Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(35)

Unified Diff: components/ntp_snippets/ntp_snippets_fetcher.h

Issue 1978513002: Getting the personalization info in chrome://snippets-internals correct. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: After code review #1 Created 4 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/ntp_snippets/ntp_snippets_fetcher.h
diff --git a/components/ntp_snippets/ntp_snippets_fetcher.h b/components/ntp_snippets/ntp_snippets_fetcher.h
index 8bc982d8d99edc55cb0aa74243665d8ebb99659e..a5d3409c00d30a28a6a2a8c1afe06d6f558acb6f 100644
--- a/components/ntp_snippets/ntp_snippets_fetcher.h
+++ b/components/ntp_snippets/ntp_snippets_fetcher.h
@@ -65,7 +65,7 @@ class NTPSnippetsFetcher : public OAuth2TokenService::Consumer,
RESULT_MAX
};
- // Enum listing all possible variants of dealing with personalization.
+ // Enumeration listing all possible variants of dealing with personalization.
enum class Personalization { kPersonal, kNonPersonal, kBoth };
NTPSnippetsFetcher(
@@ -93,7 +93,7 @@ class NTPSnippetsFetcher : public OAuth2TokenService::Consumer,
// Debug string representing the status/result of the last fetch attempt.
const std::string& last_status() const { return last_status_; }
- // Returns the last json fetched from the server.
+ // Returns the last JSON fetched from the server.
const std::string& last_json() const {
return last_fetch_json_;
}
@@ -101,10 +101,10 @@ class NTPSnippetsFetcher : public OAuth2TokenService::Consumer,
// Returns the personalization setting of the fetcher.
Personalization personalization() const { return personalization_; }
- // Does the fetcher use host restriction?
- bool UseHostRestriction() const;
+ // Does the fetcher use host restrictions?
+ bool UsesHostRestrictions() const;
// Does the fetcher use authentication to get personalized results?
- bool UseAuthentication() const;
+ bool UsesAuthentication() const;
// Overrides internal clock for testing purposes.
void SetTickClockForTesting(std::unique_ptr<base::TickClock> tick_clock) {

Powered by Google App Engine
This is Rietveld 408576698